OutputSender

Struct OutputSender 

pub struct OutputSender { /* private fields */ }
Output sender for sending packets to output pins

Implementations

Source

impl OutputSender

pub fn from_callback(callback: COutputCallback, user_data: *mut c_void) -> Self

Create a new output sender from C callback

pub fn from_callbacks( output_callback: COutputCallback, output_user_data: *mut c_void, telemetry_callback: CTelemetryCallback, telemetry_user_data: *mut c_void, ) -> Self

Create a new output sender from C callbacks.

telemetry_callback may be null if the host doesn’t provide telemetry support.

pub fn send(&self, pin: &str, packet: &Packet) -> Result<(), String>

Send a packet to an output pin

Errors

Returns an error if:

  • The pin name contains null bytes
  • The C callback returns an error
pub fn emit_telemetry( &self, event_type: &str, data: &Value, timestamp_us: Option<u64>, ) -> Result<(), String>

Emit a telemetry event to the host telemetry bus (best-effort).

data is encoded as JSON and forwarded out-of-band; it does not flow through graph pins.

If the host doesn’t provide a telemetry callback, this is a no-op.

Errors

Returns an error if:

  • event_type contains an interior NUL byte (invalid C string),
  • data cannot be serialized to JSON,
  • the host telemetry callback reports an error.